@@ -1,6 +1,6 @@
 #[allow(unused_imports)]
 #[allow(unused_macros)]
-
+#[cfg(test)]
 #[macro_use]
 extern crate diesel;
 
@@ -16,7 +16,6 @@ macro_rules! derive_id {
 			$crate::async_graphql::NewType,
 			$crate::derive_more::Display,
 			$crate::diesel_derive_newtype::DieselNewType,
-		  Identifiable,
 			$crate::serde::Deserialize,
 			$crate::serde::Serialize,
 			Clone,
@@ -59,12 +58,14 @@ mod tests {
 	}
 
 	derive_id! {
+		#[derive(Identifiable)]
 		#[table_name = "users"]
 		#[graphql(name = "UserID")]
 		pub struct UserId(#[column_name = "id"] i32);
 	}
 
 	derive_id! {
+		#[derive(Identifiable)]
 		#[table_name = "content"]
 		#[graphql(name = "ContentID")]
 		pub struct ContentId(#[column_name = "id"] i32);
